pygeodesy.interns.Str_

Package pygeodesy :: Module interns :: Class Str_ |
[frames] | no frames]

# Class Str_

    object --+
             |
    basestring --+
                 |
               str --+
                     |
                    Str_

Known Subclasses:
  - _Prefix

Extended, callable `str` class, not nameable.

See Also: Nameable and callable class Str.

Instance Methods
join_(self, *args) Join all positional `args` like `self.join(args)`. |
__call__(self, *args) Join all positional `args` like `self.join(args)`. |
Inherited from `str`: `__add__`, `__contains__`, `__eq__`, `__format__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__rmod__`, `__rmul__`, `__sizeof__`, `__str__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `format`, `index`, `isalnum`, `isalpha`, `isdigit`, `islower`, `isspace`, `istitle`, `isupper`, `join`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### join_ (self, *args) |
Join all positional `args` like `self.join(args)`. Returns: All `args` joined by this instance (Str_). Note: An other Str_ instance is returned to make the result re-callable.

### __call__ (self, *args) (Call operator) |
Join all positional `args` like `self.join(args)`. Returns: All `args` joined by this instance (Str_). Note: An other Str_ instance is returned to make the result re-callable.